@@ -23,13 +23,14 @@
  * in the United States and other countries.]
  *
  * ------------
- * $Id: CSSParserFactoryException.java 2739 2007-04-02 11:41:22Z taqua $
+ * $Id: CSSParserFactoryException.java 6489 2008-11-28 14:53:40Z tmorgner $
  * ------------
  * (C) Copyright 2006-2007, by Pentaho Corporation.
  */
 package org.jfree.layouting.input.style.parser;
 
-import org.jfree.util.StackableException;
+import org.pentaho.reporting.libraries.base.util.StackableException;
+
 
 /**
  * Creation-Date: 25.11.2005, 17:56:16
