@@ -23,15 +23,13 @@
  * in the United States and other countries.]
  *
  * ------------
- * $Id: FontConverter.java 3524 2007-10-16 11:26:31Z tmorgner $
+ * $Id: FontConverter.java 6489 2008-11-28 14:53:40Z tmorgner $
  * ------------
  * (C) Copyright 2006-2007, by Pentaho Corporation.
  */
 package org.jfree.layouting.input.swing.converter;
 
-import javax.swing.text.AttributeSet;
 import javax.swing.text.Element;
-import javax.swing.text.SimpleAttributeSet;
 import javax.swing.text.StyleConstants;
 
 import org.jfree.layouting.input.style.keys.font.FontStyle;
@@ -39,31 +37,35 @@ import org.jfree.layouting.input.style.keys.font.FontStyleKeys;
 import org.jfree.layouting.input.style.keys.font.FontWeight;
 import org.jfree.layouting.input.swing.Converter;
 import org.jfree.layouting.input.swing.ConverterAttributeSet;
-import org.jfree.util.Log;
+import org.pentaho.reporting.libraries.base.util.DebugLog;
 
 /**
  * This class handles convertions of font style attributes to css style attributes.
  */
-public class FontConverter implements Converter {
+public class FontConverter implements Converter
+{
   public FontConverter()
   {
   }
 
   /**
-   * Converts a style key and a style value to a CSS compatible style key and style value.
-   * A conversion can result in more than one key and value.
+   * Converts a style key and a style value to a CSS compatible style key and style value. A conversion can result in
+   * more than one key and value.
    *
-   * @param key The style key to convert.
-   * @param value The style value to convert.
+   * @param key     The style key to convert.
+   * @param value   The style value to convert.
    * @param cssAttr The current converted CSS attributes for the current element.
    * @param context The current Element.
    * @return The conversion result or null if no converstion has been done.
    */
-  public ConverterAttributeSet convertToCSS (final Object key, final Object value, final ConverterAttributeSet cssAttr, final Element context)
+  public ConverterAttributeSet convertToCSS(final Object key,
+                                            final Object value,
+                                            final ConverterAttributeSet cssAttr,
+                                            final Element context)
   {
-    if(key instanceof StyleConstants.FontConstants)
+    if (key instanceof StyleConstants.FontConstants)
     {
-      final StyleConstants.FontConstants fontConstant = (StyleConstants.FontConstants)key;
+      final StyleConstants.FontConstants fontConstant = (StyleConstants.FontConstants) key;
       return handleFontConstants(fontConstant, value);
     }
 
@@ -74,29 +76,29 @@ public class FontConverter implements Converter {
    * Handles the convertions of <code>(StyleConstants.FontConstants</code> key type.
    *
    * @param fontConstant The style key.
-   * @param value The style value.
+   * @param value        The style value.
    * @return The conversion result or null if no converstion has been done.
    */
-  protected ConverterAttributeSet handleFontConstants (final StyleConstants.FontConstants fontConstant,
-                                              final Object value)
+  protected ConverterAttributeSet handleFontConstants(final StyleConstants.FontConstants fontConstant,
+                                                      final Object value)
   {
     final ConverterAttributeSet attr = new ConverterAttributeSet();
 
-    if(fontConstant == StyleConstants.FontFamily)
+    if (fontConstant == StyleConstants.FontFamily)
     {
       // just attribute name conversion
       attr.addAttribute(FontStyleKeys.FONT_FAMILY.getName(), value);
 
     }
-    else if(fontConstant == StyleConstants.FontSize)
+    else if (fontConstant == StyleConstants.FontSize)
     {
       // just attribute name conversion
       attr.addAttribute(FontStyleKeys.FONT_SIZE.getName(), value);
     }
     else if (fontConstant == StyleConstants.Bold)
     {
-      final Boolean b = (Boolean)value;
-      if(Boolean.TRUE.equals(b))
+      final Boolean b = (Boolean) value;
+      if (Boolean.TRUE.equals(b))
       {
         attr.addAttribute(FontStyleKeys.FONT_WEIGHT.getName(), FontWeight.BOLD);
       }
@@ -107,8 +109,8 @@ public class FontConverter implements Converter {
     }
     else if (fontConstant == StyleConstants.Italic)
     {
-      final Boolean b = (Boolean)value;
-      if(Boolean.TRUE.equals(b))
+      final Boolean b = (Boolean) value;
+      if (Boolean.TRUE.equals(b))
       {
         attr.addAttribute(FontStyleKeys.FONT_STYLE.getName(), FontStyle.ITALIC);
       }
@@ -119,7 +121,7 @@ public class FontConverter implements Converter {
     }
     else
     {
-      Log.debug(new Log.SimpleMessage("Unkown type of font attribute", fontConstant));
+      DebugLog.log("Unkown type of font attribute: " + fontConstant);
       return null;
     }
 
