@@ -23,7 +23,7 @@
  * in the United States and other countries.]
  *
  * ------------
- * $Id: BackgroundSpecification.java 3524 2007-10-16 11:26:31Z tmorgner $
+ * $Id: BackgroundSpecification.java 6489 2008-11-28 14:53:40Z tmorgner $
  * ------------
  * (C) Copyright 2006-2007, by Pentaho Corporation.
  */
@@ -38,8 +38,8 @@ import org.jfree.layouting.input.style.keys.border.BackgroundRepeat;
 import org.jfree.layouting.input.style.values.CSSConstant;
 import org.jfree.layouting.input.style.values.CSSValuePair;
 import org.jfree.layouting.util.geom.StrictDimension;
-import org.jfree.resourceloader.Resource;
-import org.jfree.util.ObjectList;
+import org.jfree.layouting.util.ObjectList;
+import org.pentaho.reporting.libraries.resourceloader.Resource;
 
 /**
  * Holds all information that make up an element background. (No borders!)
