@@ -23,7 +23,7 @@
  * in the United States and other countries.]
  *
  * ------------
- * $Id: DocumentContext.java 2739 2007-04-02 11:41:22Z taqua $
+ * $Id: DocumentContext.java 6489 2008-11-28 14:53:40Z tmorgner $
  * ------------
  * (C) Copyright 2006-2007, by Pentaho Corporation.
  */
@@ -32,7 +32,7 @@ package org.jfree.layouting.layouter.context;
 import org.jfree.layouting.input.style.values.CSSValue;
 import org.jfree.layouting.layouter.counters.CounterStyle;
 import org.jfree.layouting.namespace.NamespaceCollection;
-import org.jfree.resourceloader.ResourceManager;
+import org.pentaho.reporting.libraries.resourceloader.ResourceManager;
 
 /**
  * The document context holds general document-wide data. It does not hold
