@@ -23,7 +23,7 @@
  * in the United States and other countries.]
  *
  * ------------
- * $Id: UrlValueFunction.java 3524 2007-10-16 11:26:31Z tmorgner $
+ * $Id: UrlValueFunction.java 6489 2008-11-28 14:53:40Z tmorgner $
  * ------------
  * (C) Copyright 2006-2007, by Pentaho Corporation.
  */
@@ -39,7 +39,7 @@ import org.jfree.layouting.layouter.model.LayoutElement;
 import org.jfree.layouting.layouter.style.functions.FunctionEvaluationException;
 import org.jfree.layouting.layouter.style.functions.FunctionUtilities;
 import org.jfree.layouting.layouter.style.values.CSSResourceValue;
-import org.jfree.resourceloader.Resource;
+import org.pentaho.reporting.libraries.resourceloader.Resource;
 
 /**
  * Creation-Date: 16.04.2006, 14:14:42
