@@ -23,17 +23,17 @@
  * in the United States and other countries.]
  *
  * ------------
- * $Id: GraphicsOutputProcessorMetaData.java 2755 2007-04-10 19:27:09Z taqua $
+ * $Id: GraphicsOutputProcessorMetaData.java 6489 2008-11-28 14:53:40Z tmorgner $
  * ------------
  * (C) Copyright 2006-2007, by Pentaho Corporation.
  */
 
 package org.jfree.layouting.modules.output.graphics;
 
-import org.jfree.fonts.registry.FontFamily;
-import org.jfree.fonts.registry.FontStorage;
 import org.jfree.layouting.input.style.keys.font.FontFamilyValues;
 import org.jfree.layouting.output.AbstractOutputProcessorMetaData;
+import org.pentaho.reporting.libraries.fonts.registry.FontStorage;
+import org.pentaho.reporting.libraries.fonts.registry.FontFamily;
 
 /**
  * Creation-Date: 02.01.2006, 19:57:08
