@@ -23,7 +23,7 @@
  * in the United States and other countries.]
  *
  * ------------
- * $Id: StrictGeomUtility.java 2739 2007-04-02 11:41:22Z taqua $
+ * $Id: StrictGeomUtility.java 6489 2008-11-28 14:53:40Z tmorgner $
  * ------------
  * (C) Copyright 2006-2007, by Pentaho Corporation.
  */
@@ -32,7 +32,7 @@ package org.jfree.layouting.util.geom;
 import java.awt.geom.Dimension2D;
 import java.awt.geom.Rectangle2D;
 
-import org.jfree.ui.FloatDimension;
+import org.pentaho.reporting.libraries.base.util.FloatDimension;
 
 /**
  * This class is the heart of the alternative geometrics toolkit. It performs
